
#undef VERSION

#undef PACKAGE

/* Header files for SIOD */
#undef HAVE_SYS_MODE_H

#undef HAVE_FNMATCH_H

#undef HAVE_CRYPT_H

#undef HAVE_SYS_MKDEV_H

#undef HAVE_FCNTL_H

/* Library files for SIOD */
#undef HAVE_SETPWFILE

#undef HAVE_GETRLIMIT

#undef HAVE_GETRUSAGE

#undef HAVE_FNMATCH

#undef HAVE_GMATCH

#undef HAVE_USLEEP

#undef HAVE_LCHOWN

#undef HAVE_STRPTIME

#undef HAVE_PUTPWENT

#undef HAVE_GETWD

/* Misc nonstandard math functions */
#undef HAVE_ACOSH

#undef HAVE_ASINH

#undef HAVE_ATANH

#undef HAVE_CBRT

#undef HAVE_DREM

#undef HAVE_EXPM1

#undef HAVE_LOG1P

/* Input contexts */
#undef HAVE_XCREATEIC

/* NDBM functions */
#undef HAVE_DBM_DIRFNO

#undef HAVE_DBM_PAGFNO

#undef HAVE_DBM_RDONLY

/* Ncurses */
#undef HAVE_RESIZETERM

#undef HAVE_BEEP

#undef HAVE_IMMEDOK

#undef HAVE_KEYPAD

#undef HAVE_LIBSDB

#undef HAVE_LIB_T1

#undef HAVE_LIB_T1X

#undef HAVE_VSNPRINTF

#undef HAVE_LIBXEXT

#undef HAVE_LIBXMU

#undef HAVE_LIBMOWITZ

#undef HAVE_LIBXPM

#undef HAVE_LIBGUILE
#undef HAVE_LIBPYTHON
#undef HAVE_LIBRUBY
#undef HAVE_LIBTCL
